<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */

if ( ! function_exists( 'korpo_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Korpo Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function korpo_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'korpo_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'korpo_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Korpo Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function korpo_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'korpo_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'korpo_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Korpo Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function korpo_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'korpo_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if about section is enabled.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[about_content_type]' )->value();
	return korpo_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[about_content_type]' )->value();
	return korpo_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[about_content_type]' )->value();
	return korpo_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[service_content_type]' )->value();
	return korpo_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section content type is page.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[service_content_type]' )->value();
	return korpo_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is custom.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[service_content_type]' )->value();
	return korpo_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if project section is enabled.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_project_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_pro_theme_options[project_section_enable]' )->value() );
}

/**
 * Check if project section content type is post.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_project_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[project_content_type]' )->value();
	return korpo_pro_is_project_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if project section content type is page.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_project_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[project_content_type]' )->value();
	return korpo_pro_is_project_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if project section content type is custom.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_project_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[project_content_type]' )->value();
	return korpo_pro_is_project_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest section is enabled.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_latest_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_pro_theme_options[latest_section_enable]' )->value() );
}

/**
 * Check if latest section content type is post.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_latest_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[latest_content_type]' )->value();
	return korpo_pro_is_latest_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if latest section content type is category.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_latest_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[latest_content_type]' )->value();
	return korpo_pro_is_latest_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if latest section content type is recent.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_latest_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'korpo_pro_theme_options[latest_content_type]' )->value();
	return korpo_pro_is_latest_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if contact section is enabled.
 *
 * @since Korpo Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function korpo_pro_is_contact_section_enable( $control ) {
	return ( $control->manager->get_setting( 'korpo_pro_theme_options[contact_section_enable]' )->value() );
}
