<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 * @return array An array of default values
 */

function korpo_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$korpo_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#000',
		'header_tagline_color'			=> '#000',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#000',
		'colorscheme'					=> 'default',
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'menu_type'						=> 'classic-menu',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Continue Reading', 'korpo-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'korpo-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'korpo-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'korpo-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'About,Service,Project,Latest',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'korpo-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// About Us
		'about_section_enable'			=> true,
		'about_sub_title'				=> esc_html__( 'Who we are', 'korpo-pro' ),
		'about_content_type'			=> 'page',
		'about_btn_label'				=> esc_html__( 'Know More', 'korpo-pro' ),
		'about_title'					=> esc_html__( 'We are innovating today for betterment of tomorrow.', 'korpo-pro' ),
		'about_description'				=> esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec lacus arcu, aliquet eu pulvinar et, aliquet ac diam. Nulla venenatis diam at lorem ultrices cursus. Vestibulum porttitor laoreet mi ac blandit.', 'korpo-pro' ),
		'about_image'					=> get_template_directory_uri() . '/assets/uploads/about-us.jpg',
		'about_layout'					=> 'image-left',

		// Service
		'service_section_enable'		=> true,
		'service_title'					=> esc_html__( 'Our Services', 'korpo-pro' ),
		'service_sub_title'					=> esc_html__( 'We help everyone with our innovative services.', 'korpo-pro' ),
		'service_btn_label'				=> esc_html__( 'View All Services', 'korpo-pro' ),
		'service_content_type'			=> 'category',
		'service_count'					=> 3,
		'service_image'					=> get_template_directory_uri() . '/assets/uploads/our-services.jpg',
		'service_layout'				=> 'image-right',

		// Project
		'project_section_enable'		=> true,
		'project_title'					=> esc_html__( 'Our Projects', 'korpo-pro' ),
		'project_btn_label'				=> esc_html__( 'View All Projects', 'korpo-pro' ),
		'project_content_type'			=> 'category',
		'project_count'					=> 4,
		'project_image'					=> get_template_directory_uri() . '/assets/uploads/our-projects.jpg',
		'project_layout'				=> 'image-left',

		// Latest
		'latest_section_enable'			=> true,
		'latest_title'					=> esc_html__( 'Latest Blogs', 'korpo-pro' ),
		'latest_btn_label'				=> esc_html__( 'View All Blogs', 'korpo-pro' ),
		'latest_content_type'			=> 'recent',
		'latest_slider_direction'		=> 'horizontal',
		'latest_count'					=> 4,
		'latest_image'					=> get_template_directory_uri() . '/assets/uploads/latest-posts.jpg',
		'latest_layout'					=> 'image-right',

		// Contact
		'contact_section_enable'		=> true,
		'contact_title'					=> esc_html__( 'Contact Us', 'korpo-pro' ),
		'contact_sub_title'				=> esc_html__( 'Get in touch with us!', 'korpo-pro' ),
		'contact_address'				=> esc_html__( '265 Street, Manbhawan, Lalitpur, Nepal', 'korpo-pro' ),
		'contact_phone'					=> esc_html__( '+00 0000000000', 'korpo-pro' ),
		'contact_email'					=> 'info@themepalace.com',
		'contact_social'				=> 'facebook.com',

	);

	$output = apply_filters( 'korpo_pro_default_theme_options', $korpo_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}