<?php
/**
 * Latest Section options
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */

// Add Latest section
$wp_customize->add_section( 'korpo_pro_latest_section', array(
	'title'             => esc_html__( 'Latest Posts','korpo-pro' ),
	'description'       => esc_html__( 'Latest Section options.', 'korpo-pro' ),
	'panel'             => 'korpo_pro_front_page_panel',
) );

// Latest content enable control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_section_enable]', array(
	'default'			=> 	$options['latest_section_enable'],
	'sanitize_callback' => 'korpo_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Korpo_Pro_Switch_Control( $wp_customize, 'korpo_pro_theme_options[latest_section_enable]', array(
	'label'             => esc_html__( 'Latest Section Enable', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'on_off_label' 		=> korpo_pro_switch_options(),
) ) );

// Latest us title setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_title]', array(
	'label'           	=> esc_html__( 'Title', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_latest_section',
	'active_callback' 	=> 'korpo_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[latest_title]', array(
		'selector'            => '#latest-posts .posts-section-wrapper .entry-container .section-header span.section-subtitle',
		'settings'            => 'korpo_pro_theme_options[latest_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_latest_title_partial',
    ) );
}

// Project btn label setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_btn_label]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'          	=> $options['latest_btn_label'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_btn_label]', array(
	'label'           	=> esc_html__( 'Button Label', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_latest_section',
	'active_callback' 	=> 'korpo_pro_is_latest_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'korpo_pro_theme_options[latest_btn_label]', array(
		'selector'            => '#latest-posts .posts-section-wrapper .more-link a',
		'settings'            => 'korpo_pro_theme_options[latest_btn_label]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'korpo_pro_latest_btn_label_partial',
    ) );
}

// Project btn link setting and control
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'korpo-pro' ),
	'section'        	=> 'korpo_pro_latest_section',
	'active_callback' 	=> 'korpo_pro_is_latest_section_enable',
	'type'				=> 'url',
) );

// latest Section background setting and control.
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_image]', array(
	'default'           => $options['latest_image'],
	'sanitize_callback' => 'korpo_pro_sanitize_image'
) );

$wp_customize->add_control(
	new WP_Customize_Image_Control( $wp_customize, 'korpo_pro_theme_options[latest_image]',
		array(
		'label'       		=> esc_html__( 'Select Background Image', 'korpo-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'korpo-pro' ), 800, 800 ),
		'section'     		=> 'korpo_pro_latest_section',
		'active_callback'	=> 'korpo_pro_is_latest_section_enable',
) ) );

// Latest us column type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_slider_direction]', array(
	'default'          	=> $options['latest_slider_direction'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_slider_direction]', array(
	'label'             => esc_html__( 'Slider Direction', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'type'				=> 'select',
	'active_callback' 	=> 'korpo_pro_is_latest_section_enable',
	'choices'			=> array( 
		'horizontal' 	=> esc_html__( 'Horizontal', 'korpo-pro' ),
		'vertical' 		=> esc_html__( 'Vertical', 'korpo-pro' ),
	),
) );

// Latest posts number control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_count]', array(
	'default'          	=> $options['latest_count'],
	'sanitize_callback' => 'korpo_pro_sanitize_number_range',
	'validate_callback' => 'korpo_pro_validate_latest_count',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_count]', array(
	'label'             => esc_html__( 'Number of Latest Posts', 'korpo-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 8. Please input the valid number and save. Then refresh the page to see the change.', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'active_callback'   => 'korpo_pro_is_latest_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 8,
		'style' => 'width: 100px;'
		),
) );

// Latest layout type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_layout]', array(
	'default'          	=> $options['latest_layout'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_layout]', array(
	'label'             => esc_html__( 'Layout', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'type'				=> 'radio',
	'active_callback' 	=> 'korpo_pro_is_latest_section_enable',
	'choices'			=> array( 
		'image-left' 	=> esc_html__( 'Image Left', 'korpo-pro' ),
		'image-right' 	=> esc_html__( 'Image Right', 'korpo-pro' ),
	),
) );

// Latest us content type control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_content_type]', array(
	'default'          	=> $options['latest_content_type'],
	'sanitize_callback' => 'korpo_pro_sanitize_select',
) );

$wp_customize->add_control( 'korpo_pro_theme_options[latest_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'type'				=> 'select',
	'active_callback' 	=> 'korpo_pro_is_latest_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'korpo-pro' ),
		'category' 	=> esc_html__( 'Category', 'korpo-pro' ),
		'recent' 	=> esc_html__( 'Recent Posts', 'korpo-pro' ),
	),
) );

for ( $i = 1; $i <= $options['latest_count']; $i++ ) :
	// latest posts drop down chooser control and setting
	$wp_customize->add_setting( 'korpo_pro_theme_options[latest_content_post_' . $i . ']', array(
		'sanitize_callback' => 'korpo_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Korpo_Pro_Dropdown_Chooser( $wp_customize, 'korpo_pro_theme_options[latest_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'korpo-pro' ), $i ),
		'section'           => 'korpo_pro_latest_section',
		'choices'			=> korpo_pro_post_choices(),
		'active_callback'	=> 'korpo_pro_is_latest_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'korpo_pro_theme_options[latest_content_category]', array(
	'sanitize_callback' => 'korpo_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Korpo_Pro_Dropdown_Taxonomies_Control( $wp_customize,'korpo_pro_theme_options[latest_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'korpo-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'korpo_pro_is_latest_section_content_category_enable'
) ) );

// recent posts description control and setting
$wp_customize->add_setting( 'korpo_pro_theme_options[latest_content_recent]', array(
	'sanitize_callback' => 'sanitize_text_field',
) );

$wp_customize->add_control( new Korpo_Pro_Note_Control( $wp_customize, 'korpo_pro_theme_options[latest_content_recent]', array(
	'label'             => esc_html__( 'Display recent posts.', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'active_callback'	=> 'korpo_pro_is_latest_section_content_recent_enable',
) ) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'korpo_pro_theme_options[latest_exclude_category]', array(
	'sanitize_callback' => 'korpo_pro_sanitize_category_list',
) ) ;

$wp_customize->add_control( new Korpo_Pro_Dropdown_Category_Control( $wp_customize,'korpo_pro_theme_options[latest_exclude_category]', array(
	'label'             => esc_html__( 'Exclude Categories', 'korpo-pro' ),
	'description'      	=> esc_html__( 'Note: Press CTRL key and select multiple categories. Posts from selected categories will be excluded.', 'korpo-pro' ),
	'section'           => 'korpo_pro_latest_section',
	'type'              => 'dropdown-categories',
	'active_callback'	=> 'korpo_pro_is_latest_section_content_recent_enable'
) ) );