<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function korpo_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( 'None', 'korpo-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}
/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function korpo_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( 'None', 'korpo-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}


if ( ! function_exists( 'korpo_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function korpo_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'korpo-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'korpo-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'korpo-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'korpo-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'korpo-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'korpo-pro' ),
        );

        $output = apply_filters( 'korpo_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'korpo_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function korpo_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'korpo-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'korpo-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'korpo-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'korpo-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'korpo-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'korpo-pro' ),
        );

        $output = apply_filters( 'korpo_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'korpo_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function korpo_pro_site_layout() {
        $korpo_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'korpo_pro_site_layout', $korpo_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'korpo_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function korpo_pro_selected_sidebar() {
        $korpo_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'korpo-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'korpo-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'korpo-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'korpo-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'korpo-pro' ),
        );

        $output = apply_filters( 'korpo_pro_selected_sidebar', $korpo_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'korpo_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function korpo_pro_sidebar_position() {
        $korpo_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'korpo_pro_sidebar_position', $korpo_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'korpo_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function korpo_pro_pagination_options() {
        $korpo_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'korpo-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'korpo-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'korpo-pro' ),
        );

        $output = apply_filters( 'korpo_pro_pagination_options', $korpo_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'korpo_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function korpo_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'korpo-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'korpo-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'korpo-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'korpo-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'korpo-pro' ),
            'spinner-circle'        => esc_html__( 'Circle', 'korpo-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'korpo-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'korpo-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'korpo-pro' ),
        );
        return apply_filters( 'korpo_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'korpo_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function korpo_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'korpo-pro' ),
            'off'       => esc_html__( 'Disable', 'korpo-pro' )
        );
        return apply_filters( 'korpo_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'korpo_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function korpo_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'korpo-pro' ),
            'off'       => esc_html__( 'No', 'korpo-pro' )
        );
        return apply_filters( 'korpo_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'korpo_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function korpo_pro_sortable_sections() {
        $sections = array(
            'about'         => esc_html__( 'About', 'korpo-pro' ),
            'service'       => esc_html__( 'Service', 'korpo-pro' ),
            'project'       => esc_html__( 'Project', 'korpo-pro' ),
            'latest'        => esc_html__( 'Latest', 'korpo-pro' ),
        );
        return apply_filters( 'korpo_pro_sortable_sections', $sections );
    }
endif;