<?php
/**
 * Contact section
 *
 * This is the template for the content of contact section
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */
if ( ! function_exists( 'korpo_pro_add_contact_section' ) ) :
    /**
    * Add contact section
    *
    *@since Korpo Pro 1.0.0
    */
    function korpo_pro_add_contact_section() {
    	$options = korpo_pro_get_theme_options();
        // Check if contact is enabled on frontpage
        $contact_enable = apply_filters( 'korpo_pro_section_status', true, 'contact_section_enable' );

        if ( true !== $contact_enable ) {
            return false;
        }

        // Render contact section now.
        korpo_pro_render_contact_section();
    }
endif;
add_action( 'korpo_pro_footer_primary_content', 'korpo_pro_add_contact_section', 10 );

if ( ! function_exists( 'korpo_pro_render_contact_section' ) ) :
  /**
   * Start contact section
   *
   * @return string contact content
   * @since Korpo Pro 1.0.0
   *
   */
   function korpo_pro_render_contact_section() {
        $options = korpo_pro_get_theme_options();
        $contact_title = ! empty( $options['contact_title'] ) ? $options['contact_title'] : '';
        $contact_sub_title = ! empty( $options['contact_sub_title'] ) ? $options['contact_sub_title'] : '';
        $contact_map = ! empty( $options['contact_map'] ) ? $options['contact_map'] : '';
        $contact_form = ! empty( $options['contact_form'] ) ? $options['contact_form'] : '';
        $contact_address = ! empty( $options['contact_address'] ) ? $options['contact_address'] : '';
        $contact_phone = ! empty( $options['contact_phone'] ) ? explode( '|', $options['contact_phone'] ) : array();
        $contact_email = ! empty( $options['contact_email'] ) ? explode( '|', $options['contact_email'] ) : array();
        $contact_social = ! empty( $options['contact_social'] ) ? explode( '|', $options['contact_social'] ) : array();
        ?>
        <section id="contact-us">
            <div class="contact-section-wrapper <?php echo ! empty( $contact_map ) ? 'has' : 'no'; ?>-featured-image">
                <?php if ( ! empty( $contact_map ) ) : ?>
                    <div id="map">
                        <?php echo do_shortcode( wp_kses_post( $contact_map ) ); ?> 
                    </div><!-- #map -->  
                <?php endif; ?>
                <div class="section-content">
                    <?php if ( ! empty( $contact_title ) || ! empty( $contact_sub_title ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $contact_title ) ) : ?>
                                <span class="section-subtitle"><?php echo esc_html( $contact_title ); ?></span>
                            <?php endif; 

                            if ( ! empty( $contact_sub_title ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $contact_sub_title ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="contact-form-wrapper">
                        <?php if ( ! empty( $contact_form ) ) : 
                            echo do_shortcode( wp_kses_post( $contact_form ) ); 
                        endif; ?>
                    </div><!-- .contact-form-wrapper -->

                    <div class="contact-address-wrapper clear">
                        <ul class="contact-address">
                            <?php if ( ! empty( $contact_address ) ) : ?>
                                <li><?php echo esc_html( $contact_address ); ?></li>
                            <?php endif; 

                            if ( ! empty( $contact_phone ) ) : ?>
                                <li>
                                    <?php foreach ( $contact_phone as $phone ) : ?>
                                        <a href="<?php echo esc_url( 'tel:' . $phone ); ?>"><?php echo esc_html( $phone ); ?></a>
                                    <?php endforeach; ?>
                                </li>
                            <?php endif; 
                            
                            if ( ! empty( $contact_email ) ) : ?>
                                <li>
                                    <?php foreach ( $contact_email as $email ) : ?>
                                        <a href="<?php echo esc_url( 'mailto:' . $email ); ?>"><?php echo esc_html( $email ); ?></a>
                                    <?php endforeach; ?>
                                </li>
                            <?php endif; ?>
                        </ul><!-- .contact-address -->

                        <?php if ( ! empty( $contact_social ) ) : ?>
                            <ul class="social-icons">
                                <?php foreach ( $contact_social as $social ) : ?>
                                    <li>
                                        <a href="<?php echo esc_url( $social ); ?>">
                                            <?php echo korpo_pro_return_social_icon( $social ); ?>
                                        </a>
                                    </li>
                                <?php endforeach; ?>
                            </ul><!-- .social-icons -->
                        <?php endif; ?>
                    </div><!-- .contact-address-wrapper -->
                </div><!-- .section-content -->
            </div><!-- .contact-section-wrapper -->
        </section><!-- #contact-us -->

    <?php }
endif;