<?php
/**
 * Project section
 *
 * This is the template for the content of project section
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */
if ( ! function_exists( 'korpo_pro_add_project_section' ) ) :
    /**
    * Add project section
    *
    *@since Korpo Pro 1.0.0
    */
    function korpo_pro_add_project_section() {
    	$options = korpo_pro_get_theme_options();
        // Check if project is enabled on frontpage
        $project_enable = apply_filters( 'korpo_pro_section_status', true, 'project_section_enable' );

        if ( true !== $project_enable ) {
            return false;
        }
        // Get project section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_pro_filter_project_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render project section now.
        korpo_pro_render_project_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_pro_get_project_section_details' ) ) :
    /**
    * project section details.
    *
    * @since Korpo Pro 1.0.0
    * @param array $input project section details.
    */
    function korpo_pro_get_project_section_details( $input ) {
        $options = korpo_pro_get_theme_options();

        // Content type.
        $project_content_type  = $options['project_content_type'];
        $project_count = ! empty( $options['project_count'] ) ? $options['project_count'] : 3;
        $content = array();
        switch ( $project_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <=  $project_count; $i++ ) {
                    if ( ! empty( $options['project_content_page_' . $i] ) )
                        $page_ids[] = $options['project_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $project_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <=  $project_count; $i++ ) {
                    if ( ! empty( $options['project_content_post_' . $i] ) )
                        $post_ids[] = $options['project_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $project_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['project_content_category'] ) ? $options['project_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $project_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = get_the_content();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// project section content details.
add_filter( 'korpo_pro_filter_project_section_details', 'korpo_pro_get_project_section_details' );


if ( ! function_exists( 'korpo_pro_render_project_section' ) ) :
  /**
   * Start project section
   *
   * @return string project content
   * @since Korpo Pro 1.0.0
   *
   */
   function korpo_pro_render_project_section( $content_details = array() ) {
        $options = korpo_pro_get_theme_options();
        $title = ! empty( $options['project_title'] ) ? $options['project_title'] : '';
        $btn_label = ! empty( $options['project_btn_label'] ) ? $options['project_btn_label'] : '';
        $btn_link = ! empty( $options['project_btn_link'] ) ? $options['project_btn_link'] : '#.';
        $background = ! empty( $options['project_image'] ) ? $options['project_image'] : '';
        $project_content_type  = $options['project_content_type'];
        $i = 1;
        $count = count( $content_details );
        $class = ! empty( $options['project_layout'] ) ? $options['project_layout'] : 'image-left';
        $class .= ! empty( $background ) ? ' has-featured-image' : ' no-featured-image';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="our-projects">
            <div class="projects-section-wrapper <?php echo esc_attr( $class ); ?>">
                <div class="featured-image" 
                <?php if ( ! empty( $background ) ) : ?>
                    style="background-image: url('<?php echo esc_url( $background ); ?>');"
                <?php endif; ?>
                >
                    <div class="overlay"></div>
                    <?php if ( ! empty( $btn_label ) ) : ?>
                        <div class="more-link">
                            <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-primary"><?php echo esc_html( $btn_label ); ?></a>
                        </div><!-- .more-link -->
                    <?php endif; ?>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <?php if ( ! empty( $title ) ) : ?>
                        <div class="section-header">
                            <span class="section-subtitle"><?php echo esc_html( $title ); ?></span>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="project-slider" data-slick='{"slidesToShow": 2, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":true, "autoplay": true, "fade": false }'>
                        <div class="slick-item">
                            <?php foreach ( $content_details as $content ) : ?>
                                <article class="<?php echo ! empty( $content['image'] ) ? 'has' : 'no'; ?>-post-thumbnail">
                                    <div class="project-content-wrapper" 
                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"
                                    <?php endif; ?>
                                    >
                                        <div class="project-deatils">
                                            <header class="entry-header">
                                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                            </header>

                                            <?php if ( 'page' !== $project_content_type ) :  ?>
                                                <div class="entry-meta">
                                                    <?php the_category( '', '', absint( $content['id'] ) ); ?>
                                                </div><!-- .entry-meta -->  
                                            <?php endif; ?>
                                        </div><!-- .project-details --> 
                                    </div><!-- .project-content-wrapper -->
                                </article>
                                <?php if ( $count > $i && $i%2 == 0 ) : ?>  
                                    </div><!-- .slick-item -->
                                    <div class="slick-item">
                                <?php endif; 
                                $i++;
                            endforeach; ?>
                        </div><!-- .slick-item -->
                    </div><!-- .section-content -->
                </div><!-- .entry-container -->
            </div>
        </section><!-- #our-projects -->
    <?php }
endif;