<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Korpo Pro
 * @since Korpo Pro 1.0.0
 */
if ( ! function_exists( 'korpo_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Korpo Pro 1.0.0
    */
    function korpo_pro_add_service_section() {
    	$options = korpo_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'korpo_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'korpo_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        korpo_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'korpo_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Korpo Pro 1.0.0
    * @param array $input service section details.
    */
    function korpo_pro_get_service_section_details( $input ) {
        $options = korpo_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_count = ! empty( $options['service_count'] ) ? $options['service_count'] : 3;
        $content = array();
        switch ( $service_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <=  $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) )
                        $page_ids[] = $options['service_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <=  $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) )
                        $post_ids[] = $options['service_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $service_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['excerpt']   = get_the_content();

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'korpo_pro_filter_service_section_details', 'korpo_pro_get_service_section_details' );


if ( ! function_exists( 'korpo_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Korpo Pro 1.0.0
   *
   */
   function korpo_pro_render_service_section( $content_details = array() ) {
        $options = korpo_pro_get_theme_options();
        $title = ! empty( $options['service_title'] ) ? $options['service_title'] : '';
        $sub_title = ! empty( $options['service_sub_title'] ) ? $options['service_sub_title'] : '';
        $btn_label = ! empty( $options['service_btn_label'] ) ? $options['service_btn_label'] : '';
        $btn_link = ! empty( $options['service_btn_link'] ) ? $options['service_btn_link'] : '#.';
        $background = ! empty( $options['service_image'] ) ? $options['service_image'] : '';
        $class = ! empty( $options['service_layout'] ) ? $options['service_layout'] : 'image-right';
        $class .= ! empty( $background ) ? ' has-featured-image' : ' no-featured-image';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <section id="our-services">
            <div class="services-section-wrapper <?php echo esc_attr( $class ); ?>">
                <div class="featured-image" 
                <?php if ( ! empty( $background ) ) : ?>
                    style="background-image: url('<?php echo esc_url( $background ); ?>');"
                <?php endif; ?>
                >
                    <div class="overlay"></div>
                    <?php if ( ! empty( $btn_label ) ) : ?>
                        <div class="more-link">
                            <a href="<?php echo esc_url( $btn_link ); ?>" class="btn btn-primary"><?php echo esc_html( $btn_label ); ?></a>
                        </div><!-- .more-link -->
                    <?php endif; ?>
                </div><!-- .featured-image -->

                <div class="entry-container">
                    <?php if ( ! empty( $title ) || ! empty( $sub_title ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $title ) ) : ?>
                                <span class="section-subtitle"><?php echo esc_html( $title ); ?></span>
                            <?php endif; 

                            if ( ! empty( $sub_title ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $sub_title ); ?></h2>
                            <?php endif; ?>
                        </div><!-- .section-header -->
                    <?php endif; ?>

                    <div class="section-content">
                        <div class="faq-group">
                            <?php foreach ( $content_details as $content ) : ?>
                                <div class="each-faq">
                                    <a class="faq-trigger" href="#">
                                        <h4><?php echo esc_html( $content['title'] ); ?></h4>
                                        <button class="icon-trigger">
                                            <?php  
                                            echo korpo_pro_get_svg( array( 'icon' => 'add' ) );
                                            echo korpo_pro_get_svg( array( 'icon' => 'close' ) );
                                            ?>
                                        </button>
                                    </a><!-- .faq-trigger -->

                                    <div class="faq-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div> <!-- .faq-content -->
                                </div><!-- .each-faq -->
                            <?php endforeach; ?>
                        </div><!-- .faq-group -->
                    </div><!-- .section-content -->
                </div><!-- .entry-container -->
            </div>
        </section><!-- #our-services -->
    <?php }
endif;